@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import ActionCategoryType, ActionOwnerType, StageTransitionTypeType
 from .paginator import (
@@ -27,8 +27,8 @@ from .paginator import (
     ListWebhooksPaginator,
 )
 from .type_defs import (
-    AcknowledgeJobOutputResponseTypeDef,
-    AcknowledgeThirdPartyJobOutputResponseTypeDef,
+    AcknowledgeJobOutputTypeDef,
+    AcknowledgeThirdPartyJobOutputTypeDef,
     ActionConfigurationPropertyTypeDef,
     ActionExecutionFilterTypeDef,
     ActionRevisionTypeDef,
@@ -37,34 +37,34 @@ from .type_defs import (
     ActionTypeSettingsTypeDef,
     ApprovalResultTypeDef,
     ArtifactDetailsTypeDef,
-    CreateCustomActionTypeOutputResponseTypeDef,
-    CreatePipelineOutputResponseTypeDef,
+    CreateCustomActionTypeOutputTypeDef,
+    CreatePipelineOutputTypeDef,
     CurrentRevisionTypeDef,
     ExecutionDetailsTypeDef,
     FailureDetailsTypeDef,
-    GetActionTypeOutputResponseTypeDef,
-    GetJobDetailsOutputResponseTypeDef,
-    GetPipelineExecutionOutputResponseTypeDef,
-    GetPipelineOutputResponseTypeDef,
-    GetPipelineStateOutputResponseTypeDef,
-    GetThirdPartyJobDetailsOutputResponseTypeDef,
-    ListActionExecutionsOutputResponseTypeDef,
-    ListActionTypesOutputResponseTypeDef,
-    ListPipelineExecutionsOutputResponseTypeDef,
-    ListPipelinesOutputResponseTypeDef,
-    ListTagsForResourceOutputResponseTypeDef,
-    ListWebhooksOutputResponseTypeDef,
+    GetActionTypeOutputTypeDef,
+    GetJobDetailsOutputTypeDef,
+    GetPipelineExecutionOutputTypeDef,
+    GetPipelineOutputTypeDef,
+    GetPipelineStateOutputTypeDef,
+    GetThirdPartyJobDetailsOutputTypeDef,
+    ListActionExecutionsOutputTypeDef,
+    ListActionTypesOutputTypeDef,
+    ListPipelineExecutionsOutputTypeDef,
+    ListPipelinesOutputTypeDef,
+    ListTagsForResourceOutputTypeDef,
+    ListWebhooksOutputTypeDef,
     PipelineDeclarationTypeDef,
-    PollForJobsOutputResponseTypeDef,
-    PollForThirdPartyJobsOutputResponseTypeDef,
-    PutActionRevisionOutputResponseTypeDef,
-    PutApprovalResultOutputResponseTypeDef,
-    PutWebhookOutputResponseTypeDef,
-    RetryStageExecutionOutputResponseTypeDef,
-    StartPipelineExecutionOutputResponseTypeDef,
-    StopPipelineExecutionOutputResponseTypeDef,
+    PollForJobsOutputTypeDef,
+    PollForThirdPartyJobsOutputTypeDef,
+    PutActionRevisionOutputTypeDef,
+    PutApprovalResultOutputTypeDef,
+    PutWebhookOutputTypeDef,
+    RetryStageExecutionOutputTypeDef,
+    StartPipelineExecutionOutputTypeDef,
+    StopPipelineExecutionOutputTypeDef,
     TagTypeDef,
-    UpdatePipelineOutputResponseTypeDef,
+    UpdatePipelineOutputTypeDef,
     WebhookDefinitionTypeDef,
 )
 
@@ -126,31 +126,36 @@ class Exceptions:
     WebhookNotFoundException: Type[BotocoreClientError]
 
 
-class CodePipelineClient:
+class CodePipelineClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
 
-    def acknowledge_job(self, *, jobId: str, nonce: str) -> AcknowledgeJobOutputResponseTypeDef:
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        CodePipelineClient exceptions.
+        """
+
+    def acknowledge_job(self, *, jobId: str, nonce: str) -> AcknowledgeJobOutputTypeDef:
         """
         Returns information about a specified job and whether that job has been received
         by the job worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#acknowledge_job)
         """
 
     def acknowledge_third_party_job(
         self, *, jobId: str, nonce: str, clientToken: str
-    ) -> AcknowledgeThirdPartyJobOutputResponseTypeDef:
+    ) -> AcknowledgeThirdPartyJobOutputTypeDef:
         """
         Confirms a job worker has received the specified job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#acknowledge_third_party_job)
         """
 
@@ -158,7 +163,7 @@ class CodePipelineClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#can_paginate)
         """
 
@@ -173,22 +178,22 @@ class CodePipelineClient:
         settings: "ActionTypeSettingsTypeDef" = None,
         configurationProperties: List["ActionConfigurationPropertyTypeDef"] = None,
         tags: List["TagTypeDef"] = None
-    ) -> CreateCustomActionTypeOutputResponseTypeDef:
+    ) -> CreateCustomActionTypeOutputTypeDef:
         """
         Creates a new custom action that can be used in all pipelines associated with
         the AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#create_custom_action_type)
         """
 
     def create_pipeline(
         self, *, pipeline: "PipelineDeclarationTypeDef", tags: List["TagTypeDef"] = None
-    ) -> CreatePipelineOutputResponseTypeDef:
+    ) -> CreatePipelineOutputTypeDef:
         """
         Creates a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#create_pipeline)
         """
 
@@ -198,7 +203,7 @@ class CodePipelineClient:
         """
         Marks a custom action as deleted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_custom_action_type)
         """
 
@@ -206,7 +211,7 @@ class CodePipelineClient:
         """
         Deletes the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_pipeline)
         """
 
@@ -214,7 +219,7 @@ class CodePipelineClient:
         """
         Deletes a previously created webhook by name.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_webhook)
         """
 
@@ -223,7 +228,7 @@ class CodePipelineClient:
         Removes the connection between the webhook that was created by CodePipeline and
         the external tool with events to be detected.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#deregister_webhook_with_third_party)
         """
 
@@ -239,7 +244,7 @@ class CodePipelineClient:
         Prevents artifacts in a pipeline from transitioning to the next stage in the
         pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#disable_stage_transition)
         """
 
@@ -249,7 +254,7 @@ class CodePipelineClient:
         """
         Enables artifacts in a pipeline to transition to a stage in a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#enable_stage_transition)
         """
 
@@ -263,65 +268,65 @@ class CodePipelineClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#generate_presigned_url)
         """
 
     def get_action_type(
         self, *, category: ActionCategoryType, owner: str, provider: str, version: str
-    ) -> GetActionTypeOutputResponseTypeDef:
+    ) -> GetActionTypeOutputTypeDef:
         """
         Returns information about an action type created for an external provider, where
         the action is to be used by customers of the external provider.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_action_type)
         """
 
-    def get_job_details(self, *, jobId: str) -> GetJobDetailsOutputResponseTypeDef:
+    def get_job_details(self, *, jobId: str) -> GetJobDetailsOutputTypeDef:
         """
         Returns information about a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_job_details)
         """
 
-    def get_pipeline(self, *, name: str, version: int = None) -> GetPipelineOutputResponseTypeDef:
+    def get_pipeline(self, *, name: str, version: int = None) -> GetPipelineOutputTypeDef:
         """
         Returns the metadata, structure, stages, and actions of a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline)
         """
 
     def get_pipeline_execution(
         self, *, pipelineName: str, pipelineExecutionId: str
-    ) -> GetPipelineExecutionOutputResponseTypeDef:
+    ) -> GetPipelineExecutionOutputTypeDef:
         """
         Returns information about an execution of a pipeline, including details about
         artifacts, the pipeline execution ID, and the name, version, and status of the
         pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline_execution)
         """
 
-    def get_pipeline_state(self, *, name: str) -> GetPipelineStateOutputResponseTypeDef:
+    def get_pipeline_state(self, *, name: str) -> GetPipelineStateOutputTypeDef:
         """
         Returns information about the state of a pipeline, including the stages and
         actions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline_state)
         """
 
     def get_third_party_job_details(
         self, *, jobId: str, clientToken: str
-    ) -> GetThirdPartyJobDetailsOutputResponseTypeDef:
+    ) -> GetThirdPartyJobDetailsOutputTypeDef:
         """
         Requests the details of a job for a third party action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_third_party_job_details)
         """
 
@@ -332,11 +337,11 @@ class CodePipelineClient:
         filter: "ActionExecutionFilterTypeDef" = None,
         maxResults: int = None,
         nextToken: str = None
-    ) -> ListActionExecutionsOutputResponseTypeDef:
+    ) -> ListActionExecutionsOutputTypeDef:
         """
         Lists the action executions that have occurred in a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_action_executions)
         """
 
@@ -346,52 +351,52 @@ class CodePipelineClient:
         actionOwnerFilter: ActionOwnerType = None,
         nextToken: str = None,
         regionFilter: str = None
-    ) -> ListActionTypesOutputResponseTypeDef:
+    ) -> ListActionTypesOutputTypeDef:
         """
         Gets a summary of all AWS CodePipeline action types associated with your
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_action_types)
         """
 
     def list_pipeline_executions(
         self, *, pipelineName: str, maxResults: int = None, nextToken: str = None
-    ) -> ListPipelineExecutionsOutputResponseTypeDef:
+    ) -> ListPipelineExecutionsOutputTypeDef:
         """
         Gets a summary of the most recent executions for a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_pipeline_executions)
         """
 
     def list_pipelines(
         self, *, nextToken: str = None, maxResults: int = None
-    ) -> ListPipelinesOutputResponseTypeDef:
+    ) -> ListPipelinesOutputTypeDef:
         """
         Gets a summary of all of the pipelines associated with your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_pipelines)
         """
 
     def list_tags_for_resource(
         self, *, resourceArn: str, nextToken: str = None, maxResults: int = None
-    ) -> ListTagsForResourceOutputResponseTypeDef:
+    ) -> ListTagsForResourceOutputTypeDef:
         """
         Gets the set of key-value pairs (metadata) that are used to manage the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_tags_for_resource)
         """
 
     def list_webhooks(
         self, *, NextToken: str = None, MaxResults: int = None
-    ) -> ListWebhooksOutputResponseTypeDef:
+    ) -> ListWebhooksOutputTypeDef:
         """
         Gets a listing of all the webhooks in this AWS Region for this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_webhooks)
         """
 
@@ -401,21 +406,21 @@ class CodePipelineClient:
         actionTypeId: "ActionTypeIdTypeDef",
         maxBatchSize: int = None,
         queryParam: Dict[str, str] = None
-    ) -> PollForJobsOutputResponseTypeDef:
+    ) -> PollForJobsOutputTypeDef:
         """
         Returns information about any jobs for AWS CodePipeline to act on.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#poll_for_jobs)
         """
 
     def poll_for_third_party_jobs(
         self, *, actionTypeId: "ActionTypeIdTypeDef", maxBatchSize: int = None
-    ) -> PollForThirdPartyJobsOutputResponseTypeDef:
+    ) -> PollForThirdPartyJobsOutputTypeDef:
         """
         Determines whether there are any third party jobs for a job worker to act on.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#poll_for_third_party_jobs)
         """
 
@@ -426,11 +431,11 @@ class CodePipelineClient:
         stageName: str,
         actionName: str,
         actionRevision: "ActionRevisionTypeDef"
-    ) -> PutActionRevisionOutputResponseTypeDef:
+    ) -> PutActionRevisionOutputTypeDef:
         """
         Provides information to AWS CodePipeline about new revisions to a source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_action_revision)
         """
 
@@ -442,11 +447,11 @@ class CodePipelineClient:
         actionName: str,
         result: "ApprovalResultTypeDef",
         token: str
-    ) -> PutApprovalResultOutputResponseTypeDef:
+    ) -> PutApprovalResultOutputTypeDef:
         """
         Provides the response to a manual approval request to AWS CodePipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_approval_result)
         """
 
@@ -456,7 +461,7 @@ class CodePipelineClient:
         """
         Represents the failure of a job as returned to the pipeline by a job worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_job_failure_result)
         """
 
@@ -472,7 +477,7 @@ class CodePipelineClient:
         """
         Represents the success of a job as returned to the pipeline by a job worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_job_success_result)
         """
 
@@ -483,7 +488,7 @@ class CodePipelineClient:
         Represents the failure of a third party job as returned to the pipeline by a job
         worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_third_party_job_failure_result)
         """
 
@@ -500,17 +505,17 @@ class CodePipelineClient:
         Represents the success of a third party job as returned to the pipeline by a job
         worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_third_party_job_success_result)
         """
 
     def put_webhook(
         self, *, webhook: "WebhookDefinitionTypeDef", tags: List["TagTypeDef"] = None
-    ) -> PutWebhookOutputResponseTypeDef:
+    ) -> PutWebhookOutputTypeDef:
         """
         Defines a webhook and returns a unique webhook URL generated by CodePipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_webhook)
         """
 
@@ -519,7 +524,7 @@ class CodePipelineClient:
         Configures a connection between the webhook that was created and the external
         tool with events to be detected.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#register_webhook_with_third_party)
         """
 
@@ -530,21 +535,21 @@ class CodePipelineClient:
         stageName: str,
         pipelineExecutionId: str,
         retryMode: Literal["FAILED_ACTIONS"]
-    ) -> RetryStageExecutionOutputResponseTypeDef:
+    ) -> RetryStageExecutionOutputTypeDef:
         """
         Resumes the pipeline execution by retrying the last failed actions in a stage.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#retry_stage_execution)
         """
 
     def start_pipeline_execution(
         self, *, name: str, clientRequestToken: str = None
-    ) -> StartPipelineExecutionOutputResponseTypeDef:
+    ) -> StartPipelineExecutionOutputTypeDef:
         """
         Starts the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#start_pipeline_execution)
         """
 
@@ -555,11 +560,11 @@ class CodePipelineClient:
         pipelineExecutionId: str,
         abandon: bool = None,
         reason: str = None
-    ) -> StopPipelineExecutionOutputResponseTypeDef:
+    ) -> StopPipelineExecutionOutputTypeDef:
         """
         Stops the specified pipeline execution.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#stop_pipeline_execution)
         """
 
@@ -567,7 +572,7 @@ class CodePipelineClient:
         """
         Adds to or modifies the tags of the given resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#tag_resource)
         """
 
@@ -575,7 +580,7 @@ class CodePipelineClient:
         """
         Removes tags from an AWS resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#untag_resource)
         """
 
@@ -584,17 +589,17 @@ class CodePipelineClient:
         Updates an action type that was created with any supported integration model,
         where the action type is to be used by customers of the action type provider.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.update_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.update_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#update_action_type)
         """
 
     def update_pipeline(
         self, *, pipeline: "PipelineDeclarationTypeDef"
-    ) -> UpdatePipelineOutputResponseTypeDef:
+    ) -> UpdatePipelineOutputTypeDef:
         """
         Updates a specified pipeline with edits or changes to its structure.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#update_pipeline)
         """
 
@@ -603,7 +608,7 @@ class CodePipelineClient:
         self, operation_name: Literal["list_action_executions"]
     ) -> ListActionExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactionexecutionspaginator)
         """
 
@@ -612,7 +617,7 @@ class CodePipelineClient:
         self, operation_name: Literal["list_action_types"]
     ) -> ListActionTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactiontypespaginator)
         """
 
@@ -621,14 +626,14 @@ class CodePipelineClient:
         self, operation_name: Literal["list_pipeline_executions"]
     ) -> ListPipelineExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelineexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelinespaginator)
         """
 
@@ -637,13 +642,13 @@ class CodePipelineClient:
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listtagsforresourcepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_webhooks"]) -> ListWebhooksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listwebhookspaginator)
         """
