@@ -35,12 +35,12 @@ from botocore.paginate import Paginator as Boto3Paginator
 from .literals import ActionOwnerType
 from .type_defs import (
     ActionExecutionFilterTypeDef,
-    ListActionExecutionsOutputResponseTypeDef,
-    ListActionTypesOutputResponseTypeDef,
-    ListPipelineExecutionsOutputResponseTypeDef,
-    ListPipelinesOutputResponseTypeDef,
-    ListTagsForResourceOutputResponseTypeDef,
-    ListWebhooksOutputResponseTypeDef,
+    ListActionExecutionsOutputTypeDef,
+    ListActionTypesOutputTypeDef,
+    ListPipelineExecutionsOutputTypeDef,
+    ListPipelinesOutputTypeDef,
+    ListTagsForResourceOutputTypeDef,
+    ListWebhooksOutputTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -56,7 +56,7 @@ __all__ = (
 
 class ListActionExecutionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactionexecutionspaginator)
     """
 
@@ -66,16 +66,16 @@ class ListActionExecutionsPaginator(Boto3Paginator):
         pipelineName: str,
         filter: "ActionExecutionFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListActionExecutionsOutputResponseTypeDef]:
+    ) -> Iterator[ListActionExecutionsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactionexecutionspaginator)
         """
 
 
 class ListActionTypesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactiontypespaginator)
     """
 
@@ -85,68 +85,68 @@ class ListActionTypesPaginator(Boto3Paginator):
         actionOwnerFilter: ActionOwnerType = None,
         regionFilter: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListActionTypesOutputResponseTypeDef]:
+    ) -> Iterator[ListActionTypesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactiontypespaginator)
         """
 
 
 class ListPipelineExecutionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelineexecutionspaginator)
     """
 
     def paginate(
         self, *, pipelineName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPipelineExecutionsOutputResponseTypeDef]:
+    ) -> Iterator[ListPipelineExecutionsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelineexecutionspaginator)
         """
 
 
 class ListPipelinesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelinespaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPipelinesOutputResponseTypeDef]:
+    ) -> Iterator[ListPipelinesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelinespaginator)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listtagsforresourcepaginator)
     """
 
     def paginate(
         self, *, resourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTagsForResourceOutputResponseTypeDef]:
+    ) -> Iterator[ListTagsForResourceOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listtagsforresourcepaginator)
         """
 
 
 class ListWebhooksPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listwebhookspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListWebhooksOutputResponseTypeDef]:
+    ) -> Iterator[ListWebhooksOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listwebhookspaginator)
         """
